@@ -4,11 +4,6 @@
 
 package Data::Dump::Color;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-03'; # DATE
-our $DIST = 'Data-Dump-Color'; # DIST
-our $VERSION = '0.249'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use subs qq(dump);
@@ -20,13 +15,19 @@ require Exporter;
 @EXPORT = qw(dd ddx);
 @EXPORT_OK = qw(dump pp dumpf quote);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2025-02-21'; # DATE
+our $DIST = 'Data-Dump-Color'; # DIST
+our $VERSION = '0.250'; # VERSION
+
 $DEBUG = $ENV{DEBUG};
 
 use overload ();
 use vars qw(%seen %refcnt @fixup @cfixup %require $TRY_BASE64 @FILTERS $INDENT);
 use vars qw($COLOR $COLOR_THEME $INDEX $LENTHRESHOLD);
 
-require Win32::Console::ANSI if $^O =~ /Win/;
+require # hide from cpanspec
+    Win32::Console::ANSI if $^O =~ /Win/;
 
 my $lan_available;
 eval {
@@ -790,7 +791,7 @@ Data::Dump::Color - Like Data::Dump, but with color
 
 =head1 VERSION
 
-This document describes version 0.249 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2023-02-03.
+This document describes version 0.250 of Data::Dump::Color (from Perl distribution Data-Dump-Color), released on 2025-02-21.
 
 =head1 SYNOPSIS
 
@@ -802,10 +803,18 @@ Use it like you would Data::Dump, e.g.:
 
 Sample screenshots:
 
-=for html <img src="https://st.aticpan.org/source/PERLANCAR/Data-Dump-Color-0.249/share/images/Screenshot_20210624_071713.png" />
+=begin html
+
+<img src="https://st.aticpan.org/source/PERLANCAR/Data-Dump-Color-0.250/share/images/Screenshot_20210624_071713%2Epng" />
+
+=end html
 
 
-=for html <img src="https://st.aticpan.org/source/PERLANCAR/Data-Dump-Color-0.249/share/images/Screenshot_20210624_071341.png" />
+=begin html
+
+<img src="https://st.aticpan.org/source/PERLANCAR/Data-Dump-Color-0.250/share/images/Screenshot_20210624_071341%2Epng" />
+
+=end html
 
 
 This module aims to be a drop-in replacement for L<Data::Dump>. It adds colors
@@ -990,7 +999,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2021, 2018, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
